nbxmpp

Package nbxmpp |
[hide private]
[frames] | no frames]

# Package nbxmpp

source code

This is a fork of the xmpppy jabber python library. Most of the code is inherited but has been extended by implementation of non-blocking transports and new features like BOSH.

Most of the xmpp classes are ancestors of PlugIn class to share a single set of methods in order to compile a featured and extensible XMPP client.

Thanks and credits to the xmpppy developers. See: http://xmpppy.sourceforge.net/

Submodules | [hide private]
nbxmpp.auth_nb: Provides plugs for SASL and NON-SASL authentication mechanisms. Can be used both for client and transport authentication nbxmpp.bosh nbxmpp.c14n: XML canonicalisation methods (for XEP-0116) nbxmpp.client_nb: Client class establishs connection to XMPP Server and handles authentication nbxmpp.dispatcher_nb: Main xmpp decision making logic. Provides library with methods to assign different handlers to different XMPP stanzas and namespaces nbxmpp.features_nb: Different stuff that wasn't worth separating it into modules (Registration, Privacy Lists, ...) nbxmpp.idlequeue: Idlequeues are Gajim's network heartbeat. Transports can be plugged as idle objects and be informed about possible IO nbxmpp.plugin: Provides PlugIn class functionality to develop extentions for xmpppy nbxmpp.protocol: Protocol module contains tools that are needed for processing of xmpp-related data structures, including jabber-objects like JID or different stanzas and sub- stanzas) handling routines nbxmpp.proxy_connectors: Module containing classes for proxy connecting. So far its HTTP CONNECT and SOCKS5 proxy nbxmpp.roster_nb: Simple roster implementation. Can be used though for different tasks like mass-renaming of contacts. nbxmpp.simplexml: Simplexml module provides xmpppy library with all needed tools to handle XML nodes and XML streams. I'm personally using it in many other separate projects. It is designed to be as standalone as possible nbxmpp.smacks nbxmpp.stringprepare nbxmpp.tls_nb nbxmpp.transports_nb: Transports are objects responsible for connecting to XMPP server and putting data to wrapped sockets in in desired form (SSL, TLS, TCP, for HTTP proxy, for SOCKS5 proxy...)

Variables | [hide private]
| __package__ = ``'``nbxmpp``'``

Imports: NS_MUC_ADMIN, STREAM_NOT_AUTHORIZED, NS_FILE, Error, NS_PUBSUB_EVENT, NS_RECEIPTS, STREAM_CONNECTION_TIMEOUT, STREAM_IMPROPER_ADDRESSING, NS_PING, ERR_GONE, Conflict, NS_PHYSLOC, NS_CHATTING, ERR_CONFLICT, NS_COMPRESS, NS_HASHES_SHA1, NS_AGENTS, NS_CAPTCHA, NS_MOOD, ERR_NOT_AUTHORIZED, UnsupportedVersion, NS_BROWSING, ERR_INTERNAL_SERVER_ERROR, HostUnknown, SASL_INCORRECT_ENCODING, NS_MUC_OWNER, NS_ACTIVITY, NS_ARCHIVE_MANUAL, NS_JINGLE_RTP_AUDIO, string, NS_PRESENCE, STREAM_INTERNAL_SERVER_ERROR, NS_CHATSTATES, NS_LAST, ERR_REDIRECT, isErrorNode, Acks, NS_GROUPCHAT, Protocol, ERR_FEATURE_NOT_IMPLEMENTED, NS_GATEWAY, NS_DISCO_ITEMS, NS_MUC_CONFIG, ConnectionTimeout, NS_BIND, NS_JINGLE_ERRORS, NS_XMPP_STREAMS, NS_IQ, ERR_RESOURCE_CONSTRAINT, NS_CLIENT, NS_FORWARD, SASL_INVALID_AUTHZID, NS_EVENT, STREAM_POLICY_VIOLATION, NS_JINGLE_IBB, NS_DATA_LAYOUT, NS_TUNE, InvalidID, stream_exceptions, NS_HASHES_SHA256, NS_CARBONS, NS_ROSTER, NS_STANZAS, NS_HTTP_BIND, isResultNode, NS_TIME_REVISED, UnsupportedStanzaType, NS_MUC_UNIQUE, ERR_SERVICE_UNAVAILABLE, NS_PUBKEY_PUBKEY, NS_AMP, STREAM_UNDEFINED_CONDITION, NS_CONFERENCE, NS_MAM, NS_DISCO, NS_RSM, NS_BLOCKING, ERRORS, NS_STREAM, NS_HASHES, HostGone, RemoteConnectionFailed, NS_ESESSION, NotAuthorized, STREAM_BAD_FORMAT, NS_JINGLE_FILE_TRANSFER, NS_LOCATION, NS_ARCHIVE_AUTO, NS_DIALBACK, SASL_ABORTED, NS_AUTH, BadFormat, NS_BOOKMARKS, NS_VCARD, STREAM_HOST_GONE, DataForm, ERR_REMOTE_SERVER_NOT_FOUND, NS_XHTML, JID, InvalidXML, NS_SI, PolicyViolation, NS_SASL, NS_JINGLE_RAW_UDP, NS_SESSION, STREAM_INVALID_FROM, StreamError, NS_CAPS, NS_PUBSUB_OWNER, NS_HASHES_SHA512, NS_AMP_ERRORS, NS_BROWSE, NS_CORRECT, NS_ROSTERX, ERR_UNDEFINED_CONDITION, NS_TLS, NS_ATTENTION, NS_DATA, NS_SERVER, ImproperAddressing, ERR_REMOTE_SERVER_TIMEOUT, NS_JINGLE_ICE_UDP, NS_IBB, DataField, ERR_REGISTRATION_REQUIRED, NS_TIME, NS_PROFILE, Message, NS_SECLABEL, NS_XHTML_IM, NS_PRIVACY, NS_GMAILNOTIFY, BadNamespacePrefix, NS_CONDITIONS, UnsupportedEncoding, NS_FEATURE, STREAM_UNSUPPORTED_VERSION, SASL_NOT_AUTHORIZED, SeeOtherHost, Node, NS_JINGLE_RTP, SystemShutdown, NS_WAITINGLIST, NS_ARCHIVE_MANAGE, NS_SSN, NS_DELAY2, SASL_MECHANISM_TOO_WEAK, InvalidNamespace, NS_COMPONENT_1, Iq, NS_ARCHIVE_PREF, Hashes, ERR_JID_MALFORMED, STREAM_INVALID_XML, NS_INVISIBLE, NS_JINGLE_RTP_VIDEO, NS_PRIVATE, NS_VERSION, STREAM_UNSUPPORTED_ENCODING, ERR_NOT_ALLOWED, NS_GAMING, NS_OFFLINE, STREAM_SYSTEM_SHUTDOWN, NS_MUC_USER, NS_VCARD_UPDATE, NS_ATOM, ascii_upper, NS_STREAMS, STREAM_HOST_UNKNOWN, ERR_BAD_REQUEST, hashlib, NS_GTALKSETTING, InvalidFrom, NS_ENCRYPTED, UndefinedCondition, NS_RPC, NS_STANZA_CRYPTO, NS_SIGNED, NS_NICK, ERR_PAYMENT_REQUIRED, NS_PUBSUB, NS_MESSAGE, NS_JINGLE_XTLS, NS_DATA_MEDIA, STREAM_XML_NOT_WELL_FORMED, XMLNotWellFormed, NS_REGISTER, STREAM_SEE_OTHER_HOST, NS_BYTESTREAM, NS_DELAY, NS_VACATION, NS_PUBSUB_PUBLISH_OPTIONS, STREAM_BAD_NAMESPACE_PREFIX, NS_GEOLOC, NS_ARCHIVE, NS_ROSTERNOTES, NS_SI_PUB, NS_DATA_VALIDATE, ERR_RECIPIENT_UNAVAILABLE, NS_ESESSION_INIT, SASL_TEMPORARY_AUTH_FAILURE, NS_PUBKEY_REVOKE, NS_JINGLE_BYTESTREAM, NodeBuilder, SASL_INVALID_MECHANISM, NS_ROSTER_VER, NS_VIEWING, NS_COMMANDS, NS_AVATAR, NodeProcessed, Presence, STREAM_CONFLICT, ResourceConstraint, STREAM_RESOURCE_CONSTRAINT, NS_STREAM_MGMT, ERR_UNEXPECTED_REQUEST, time, NS_X_OOB, ERR_SUBSCRIPTION_REQUIRED, ERR_ITEM_NOT_FOUND, STREAM_INVALID_NAMESPACE, NS_SEARCH, STREAM_REMOTE_CONNECTION_FAILED, BOSHBody, NS_ADDRESS, NS_COMPONENT_ACCEPT, STREAM_INVALID_ID, RestrictedXML, NS_SECLABEL_CATALOG, STREAM_RESTRICTED_XML, NS_DISCO_INFO, STREAM_UNSUPPORTED_STANZA_TYPE, InternalServerError, NS_PUBKEY_ATTEST, NS_MUC, ERR_NOT_ACCEPTABLE, NS_JINGLE, NS_BOB, NS_HASHES_MD5, NS_HTTP_AUTH, ERR_FORBIDDEN, ErrorNode, simplexml, protocol, auth_nb, transports_nb, roster_nb, dispatcher_nb, features_nb, idlequeue, bosh, tls_nb, proxy_connectors, NonBlockingClient, PlugIn, Smacks, client_nb, plugin, smacks

Variables Details | [hide private]

  ### __package__ Value:
      'nbxmpp'